# Engineering Feature

A specific type of engineering feature object is designed for each type of engineering feature.

## Create engineering features

```{eval-rst}
.. autoclass:: abaqus.EngineeringFeature.EngineeringFeature.EngineeringFeature
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.EngineeringFeature.Crack.Crack
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.Fastener.Fastener
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.Inertia.Inertia
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.SpringDashpot.SpringDashpot
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.AssembledFastener.AssembledFastener
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.ContourIntegral.ContourIntegral
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.DebondVCCT.DebondVCCT
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.DiscreteFastener.DiscreteFastener
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.EngineeringFeatureBase.EngineeringFeatureBase
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.HeatCapacitance.HeatCapacitance
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.NonstructuralMass.NonstructuralMass
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.PointFastener.PointFastener
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.PointMassInertia.PointMassInertia
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.SpringDashpotToGround.SpringDashpotToGround
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.TwoPointSpringDashpot.TwoPointSpringDashpot
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.EngineeringFeature.XFEMCrack.XFEMCrack
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
